@@ -315,7 +315,7 @@ impl Vm {
                     for link in &node.input_links {
                         match link {
                             Link::NodeIndexed(id, _) => {
-                                let from = *nodes_map.get(&id).unwrap();
+                                let from = *nodes_map.get(id).unwrap();
                                 let to = *nodes_map.get(&node.id).unwrap();
                                 graph.add_edge(from, to, ());
                             }
@@ -413,7 +413,7 @@ impl Vm {
                                     match link {
                                         Link::NodeIndexed(id, _) => {
                                             let to = *nodes_map.get(&node.id).unwrap();
-                                            let from = *nodes_map.get(&id).unwrap();
+                                            let from = *nodes_map.get(id).unwrap();
                                             graph.add_edge(from, to, ());
                                         }
                                         Link::None => {}
@@ -515,7 +515,7 @@ impl Vm {
                         match link {
                             Link::NodeIndexed(id, _) => {
                                 let to = *nodes_map.get(&node.id).unwrap();
-                                let from = *nodes_map.get(&id).unwrap();
+                                let from = *nodes_map.get(id).unwrap();
                                 graph.add_edge(from, to, ());
                             }
                             Link::None => {}
@@ -785,7 +785,7 @@ impl Vm {
                     VmJump::Loop(id) => {
                         let node = event.get_node(&id, self)?;
                         if let NodeType::Loop(loop_) = &node.node_type {
-                            event.go_to_node(&loop_, self)?;
+                            event.go_to_node(loop_, self)?;
                         } else {
                             return Err(VmError::NodeIsNotALoop(id));
                         }
@@ -1203,7 +1203,7 @@ impl VmEvent {
         if let Some(context) = self.contexts.last() {
             if let Some(current) = context.current {
                 if let Some(node_ref) = context.execution.get(current) {
-                    if let Ok(node) = self.get_node(&node_ref, vm) {
+                    if let Ok(node) = self.get_node(node_ref, vm) {
                         return Some(node);
                     }
                 }
